pub(crate) struct EncryptionKey<P>where
P: PkeParams,{
t_hat: NttVector<BaseField, P::K>,
rho: B32,
}Expand description
An EncryptionKey provides the ability to encrypt a value so that it can only be
decrypted by the holder of the corresponding decapsulation key.
Fields
t_hat: NttVector<BaseField, P::K>rho: B32Implementations
Sourceimpl<P> EncryptionKey<P>where
P: PkeParams,
impl<P> EncryptionKey<P>where
P: PkeParams,
Sourcepub(crate) fn encrypt(&self, message: &B32, randomness: &B32) -> Ciphertext<P>
pub(crate) fn encrypt(&self, message: &B32, randomness: &B32) -> Ciphertext<P>
Encrypt the specified message for the holder of the corresponding decryption key, using the
provided randomness, according the K-PKE.Encrypt procedure.
Sourcepub(crate) fn to_bytes(&self) -> Array<u8, <P as PkeParams>::EncryptionKeySize>
pub(crate) fn to_bytes(&self) -> Array<u8, <P as PkeParams>::EncryptionKeySize>
Represent this encryption key as a byte array (t_hat || rho)
Sourcepub(crate) fn from_bytes(
enc: &Array<u8, <P as PkeParams>::EncryptionKeySize>,
) -> Result<Self, InvalidKey>
pub(crate) fn from_bytes( enc: &Array<u8, <P as PkeParams>::EncryptionKeySize>, ) -> Result<Self, InvalidKey>
Parse an encryption key from a byte array (t_hat || rho).
Errors
Returns InvalidKey in the event that the key fails the encapsulation key checks
specified in FIPS 203 7.2.